Application developer guide
===========================

Using Weblate for translating your projects can bring you quite a lot of
benefits. It's only up to you how much of that you will use.

.. toctree::

    starting
    alerts
    community
    translations
    review
    share
    reporting
